mod renderer;

use anyhow::Result;
use crawl::winit::event::{Event, WindowEvent};
use renderer::VoxelRenderer;

fn main() -> Result<()> {
    env_logger::init();
    let (mut context, event_loop) = pollster::block_on(
        crawl::ContextBuilder::new()
            .with_title("BEAVER")
            .with_vsync(false)
            .build(),
    )?;
    let renderer = VoxelRenderer::new(&context)?;

    event_loop.run(|event, elwt| match event {
        Event::WindowEvent { window_id, event } if window_id == context.window.id() => {
            if context.handle_window_event(&event, elwt) {
                return;
            }

            if let WindowEvent::RedrawRequested = event {
                if let Err(err) = renderer.render(&context) {
                    log::error!("{err:?}");
                }

                context.window.request_redraw();
            }
        }
        _ => (),
    })?;

    Ok(())
}
